@@ -1,4 +1,4 @@
-# amazon.rb $Revision: 1.6 $
+# amazon.rb $Revision: 1.8 $
 #
 # isbn_image_left: ꤷISBNνƤclass="left"ɽ
 #   ѥ᥿:
@@ -91,7 +91,7 @@ def getAmazon( asin )
         end
 
         item_url = nil
-        item_name = nil
+        item_name = asin
         img_url = nil
         img_name = nil
         img_height = nil
@@ -114,10 +114,10 @@ def getAmazon( asin )
                                 response, = http.get( path )
                                 response.body.each do |line|
                                         line = NKF::nkf( "-e", line )
-                                        if line =~ /^Amazon.co.jp (.*)<.*$/
+                                        if line =~ /^Amazon.co.jp[:](.*)$/
                                                 item_name = CGI::escapeHTML(CGI::unescapeHTML($1))
                                         end
-                                        if line =~ /(<img src="(http\:\/\/images-jp\.amazon\.com\/images\/P\/(.*MZZZZZZZ_?.jpg))".*?>)/i
+                                        if line =~ /(<img src="(http\:\/\/images-jp\.amazon\.com\/images\/P\/(.*[ML]ZZZZZZZ_?.jpg))".*?>)/i
                                                 img_tag = $1
                                                 img_url = $2
                                                 img_name = $3
