@@ -1,10 +1,10 @@
-# $Id$
+# $Id: category.rb,v 1.5 2004/02/15 02:48:35 hitoshi Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
-# You can redistribute it and/or modify it under the terms of
-# the Ruby's licence.#
 
 def category_list(*category)
   category_re = /^\(([^\)]+?)\)/
+
+  category.collect! {|a| a.unescapeHTML}
   
   l = Hash::new
   @db.page_info.each do |a|
@@ -31,7 +31,7 @@ def category_list(*category)
     p.each do |a|
       name = a[0]
       tm = a[1][:last_modified]
-      s << "<li>#{format_date( tm )}: #{Hiki::Util::anchor(name)}</li>\n"
+      s << "<li>#{format_date( tm )}: #{hiki_anchor(name.escape, page_name(name))}\n"
     end
     s << "</ul>\n"
   end
