@@ -1,4 +1,4 @@
-# $Id: trackback.rb,v 1.9 2005/06/07 09:10:55 fdiary Exp $
+# $Id: trackback.rb,v 1.10 2005/07/13 05:03:20 fdiary Exp $
 # Copyright (C) 2004 Kazuhiko <kazuhiko@fdiary.net>
 
 def trackback
@@ -26,8 +26,8 @@ def trackback_post
   lines.each do |l|
     if /^\{\{trackback\}\}/ =~ l && flag == false
       content << "#{l}\n"
-      content << %Q!* trackback : [[#{title} (#{blog_name})|#{url}]] (#{format_date(Time::now)})\n!
-      content << %Q!#{shorten(excerpt).split(/\n/).collect{|s| %Q|""#{s}\n|}}\n!
+      content << %Q!* trackback : #{@conf.parser.link( url, "#{title} (#{blog_name})" )} (#{format_date(Time::now)})\n!
+      content << @conf.parser.blockquote( shorten( excerpt ) )
       flag = true
     else
       content << l
